@@ -4,10 +4,10 @@
 
 context("fullmatch function")
 
-# test whether two matches are the same. Uses all.equal exceedances to
-# ignore errors below some tolerance. After checking those, strips
+# test whether two matches are the same. Uses all.equal on exceedances
+# to ignore errors below some tolerance. After checking those, strips
 # attributes that may differ but not break `identical` status.
-match_equal <- function(match1, match2) {
+match_equal <- function(match1, match2, ignore.solver = TRUE) {
   expect_true(all.equal(attr(match1, "exceedances"),
                         attr(match2, "exceedances")))
 
@@ -17,6 +17,10 @@ match_equal <- function(match1, match2) {
   attr(match2, "exceedances") <- NULL
   attr(match1, "call") <- NULL
   attr(match2, "call") <- NULL
+  if (!ignore.solver) {
+    attr(match1, "solver") <- NULL
+    attr(match2, "solver") <- NULL
+  }
 
   expect_true(identical(match1, match2))
 }
@@ -195,8 +199,6 @@ test_that("Reversion Test: Proper labeling of NAs", {
 
   d <- match_on(scores, z = Z, within = exactMatch(Z ~ B))
   expect_warning(res <- pairmatch(caliper(d, 2)))
-
-  expect_equal(sum(is.na(res)), 9)
 })
 
 test_that("Results are in 'data order'", {
@@ -644,11 +646,11 @@ test_that("Edge case of only (1,1)-subproblems (#211)",
                         )
     data_sm  <- subset(data, fac=="a")
     expect_silent(f1  <- fullmatch(setNames(data_sm$x, rownames(data_sm)),
-                                   z=data_sm$z, 
+                                   z=data_sm$z,
                                    data = data_sm
                                    )
                   )
-    expect_silent(f2  <- fullmatch(z~x+strata(fac), data = data))    
+    expect_silent(f2  <- fullmatch(z~x+strata(fac), data = data))
 })
 test_that("Problems w/ fewer controls than treatment don't break mean.controls", {
 
@@ -704,3 +706,37 @@ test_that("If matching fails, we should give a warning", {
                            within = exactMatch(pr ~ pt, data = nuclearplants)),
                  "Matching failed")
 })
+
+test_that("LEMON solvers", {
+
+  # While all solves give the same solution to this problem, this needn't be
+  # true in all cases, so if this starts randomly erroring, as long as all
+  # solvers give reasonable results, this test can be dropped.
+
+  data("nuclearplants")
+  f1 <- fullmatch(pr ~ cost + t1, min.controls = 1, max.controls = 3, data = nuclearplants)
+  f2 <- fullmatch(pr ~ cost + t1, min.controls = 1, max.controls = 3, data = nuclearplants,
+                  solver = "LEMON")
+  f3 <- fullmatch(pr ~ cost + t1, min.controls = 1, max.controls = 3, data = nuclearplants,
+                  solver = LEMON("CycleCancelling"))
+  f4 <- fullmatch(pr ~ cost + t1, min.controls = 1, max.controls = 3, data = nuclearplants,
+                  solver = LEMON("CapacityScaling"))
+  f5 <- fullmatch(pr ~ cost + t1, min.controls = 1, max.controls = 3, data = nuclearplants,
+                  solver = LEMON("CostScaling"))
+  f6 <- fullmatch(pr ~ cost + t1, min.controls = 1, max.controls = 3, data = nuclearplants,
+                  solver = LEMON("NetworkSimplex"))
+
+  match_equal(f1, f2, ignore.solver = FALSE)
+  match_equal(f1, f3, ignore.solver = FALSE)
+  match_equal(f1, f4, ignore.solver = FALSE)
+  match_equal(f1, f5, ignore.solver = FALSE)
+  match_equal(f1, f6, ignore.solver = FALSE)
+
+  if (requireNamespace("rrelaxiv", quietly = TRUE)) {
+    f7 <- fullmatch(pr ~ cost + t1, min.controls = 1, max.controls = 3, data = nuclearplants,
+                    solver = "RELAX-IV")
+    match_equal(f1, f7, ignore.solver = FALSE)
+  }
+
+
+})
